SDIF Sound Description Interchange Format Matlab (IRCAM, Analyse/Synthèse)

# SDIFTM
Sound Description Interchange Format
extensions for Matlab ®

Copyright (C) 1997-2001 Analyse/Synthèse

Diemo Schwarz, Axel Röbel, Patrice Tisserand

This page's URL: http://www.ircam.fr/sdif/download/sdif-matlab

See also the freesoftware@ircam wiki which contains example matlab code, and general user-driven documentation about SDIF and other Ircam Free Software.

sdif-matlab-readme

sdif-matlab-0.3.0-src.tar.gz
sdif-matlab-0.3.0.tar.gz (only matlab 6 for linux)
sdif-matlab-0.3.0-winxp.zip (for Matlab 7 on Windows XP, thanks to Geoffroy Peeters)
sdif-matlab-0.3.0-macosx.zip (for Matlab 7 on Mac OSX)

sdif-matlab-0.2.1b-src.tar.gz
sdif-matlab-0.2.1b.tar.gz
sdif-matlab-0.2.1-src.tar.gz
sdif-matlab-0.2.1.tar.gz
sdif-matlab-0.2.0-src.tar.gz
sdif-matlab-0.2.0.tar.gz

sdif-matlab-0.1.9-src.tar.gz
sdif-matlab-0.1.9.tar.gz
sdif-matlab-0.1.8b-src.tar.gz
sdif-matlab-0.1.8b.tar.gz
sdif-matlab-0.1.8-src.tar.gz
sdif-matlab-0.1.8.tar.gz
sdif-matlab-0.1.7.tar.gz
sdif-matlab-0.1.7b.tar.gz
sdif-matlab-0.1.6.tar.gz
sdif-matlab-0.1.5.tar.gz
sdif-matlab-0.1.4.tar.gz
sdif-matlab-0.1.3.tar.gz

SDIF is a registered trademark, registered September 23, 1999 at INPI (Institut National de la Proprieté Industrielle), Paris, France for IRCAM - Centre Georges Pompidou, registration number 99/814815.